@@ -1,3 +1,7 @@
+import pytest
+
+from ..session import OpsAuthenticationError
+from ..session import session
 from .model.search import Inpadoc
 
 
@@ -9,13 +13,14 @@ class TestPublished:
         assert sum(1 for c in countries if c == "US") >= 1
 
     def test_get_biblio_from_result(self):
-        result = Inpadoc.objects.filter(applicant="Google").first().biblio
+        doc = Inpadoc.objects.filter(applicant="Google").first()
+        result = doc.biblio
         assert result.title is not None
 
     def test_get_claims_from_result(self):
         result = Inpadoc.objects.get("WO2009085664A2")
         assert len(result.claims.claims) == 20
-        assert len(result.claims.claim_text) == 4833
+        assert len(result.claims.claim_text) == 4830
 
     def test_get_description_from_result(self):
         result = Inpadoc.objects.get("WO2009085664A2")
@@ -40,3 +45,14 @@ class TestPublished:
     def test_issue_41(self):
         result = Inpadoc.objects.get("JP2005533465A").biblio
         assert result.title == None
+
+    def test_issue_76_no_credential(self):
+        key = session.key
+        session.key = None
+        with pytest.raises(OpsAuthenticationError):
+            pub = Inpadoc.objects.get("EP3082535A1")
+        session.key = key
+
+    def test_issue_76_with_credential(self):
+        pub = Inpadoc.objects.get("EP3082535A1")
+        assert pub.biblio.title == "AUTOMATIC FLUID DISPENSER"
