@@ -1,5 +1,4 @@
 from patent_client.epo.ops.util import Schema
-from patent_client.util.xml import ListField
 from yankee.xml import fields as f
 
 
@@ -16,4 +15,4 @@ class SearchSchema(Schema):
     num_results = f.Int(".//ops:biblio-search/@total-result-count")
     begin = f.Int(".//ops:range/@begin")
     end = f.Int(".//ops:range/@end")
-    results = ListField(InpadocSchema, ".//ops:search-result/ops:publication-reference")
+    results = f.List(InpadocSchema, ".//ops:search-result/ops:publication-reference")
